import sys

UNSET = object()

def parse_ast(code, filename=None, mode=None):
    if not filename:
        filename = '<string>'
    if not mode:
        mode = "exec"
    if sys.version_info >= (3, 2):
        return compile(code, filename, mode, ast.PyCF_ONLY_AST, optimize=0)
    else:
        return compile(code, filename, mode, ast.PyCF_ONLY_AST)

if sys.version_info >= (2,6):
    def compile_ast(tree, filename=None, mode=None):
        """
        Compile AST to bytecode.
        """
        if not filename:
            filename = '<string>'
        if not mode:
            mode = "exec"
        return compile(tree, filename, mode)

from astoptimizer.compatibility import ast
from astoptimizer.config import Config
from astoptimizer.optimizer import Optimizer

def optimize_ast(tree, config=None):
    """
    Optimize an AST with the specified config (or with default config).
    Return the optimized AST
    """
    optimizer = Optimizer(config)
    return optimizer.optimize(tree)

if sys.version_info >= (2,6):
    def optimize_code(code, filename=None, mode=None, config=None):
        """
        Compile code to bytecode using the AST optimizer with specified config
        (or default config).
        """
        tree = parse_ast(code, filename, mode)
        optimizer = Optimizer(config)
        tree = optimizer.optimize(tree)
        return compile_ast(tree, filename, mode)

