import sys

PYTHON3 = sys.version_info >= (3,)

try:
    # Check if the patch to test Python without its peephole has been
    # applied
    PyCF_DISABLE_PEEPHOLE = 0x1000
    compile("1+1", "<ast>", "exec", PyCF_DISABLE_PEEPHOLE)
except ValueError:
    # No worry, the patch is optionnal, even for unit tests
    PyCF_DISABLE_PEEPHOLE = 0

_SINGLETONS = set(id(obj) for obj in (None, True, False))
if PYTHON3:
    BYTES_TYPE = bytes
    UNICODE_TYPE = str
    def u(text):
        return text
    def b(text):
        return text.encode('latin1')
else:
    BYTES_TYPE = str
    UNICODE_TYPE = unicode
    def u(text):
        return unicode(text, "unicode_escape")
    def b(text):
        return text
NATIVE_STR = str

STR_TYPES = (BYTES_TYPE, UNICODE_TYPE)
if PYTHON3:
    INT_TYPES = (int,)
else:
    INT_TYPES = (int, long)
FLOAT_TYPES = INT_TYPES + (float,)
COMPLEX_TYPES = INT_TYPES + (float, complex)

IMMUTABLE_TYPES = COMPLEX_TYPES + STR_TYPES + (type(None),)
IMMUTABLE_ITERABLE_TYPES = STR_TYPES + (tuple, frozenset)

def is_singleton(config, value):
    return id(value) in _SINGLETONS

def is_immutable(value):
    if isinstance(value, IMMUTABLE_TYPES):
        return True
    if isinstance(value, IMMUTABLE_ITERABLE_TYPES):
        return all(is_immutable(item) for item in value)
    return False

def is_bytes_ascii(data):
    return all(ord(byte) < 128 for byte in data)

try:
    import ast
except ImportError:
    from astoptimizer import ast_python27 as ast

