"""
Enable optimizations on the math module.
"""

from astoptimizer.compatibility import FLOAT_TYPES
from astoptimizer.config import Function
import math
import sys

def check_sqrt(config, args):
    arg = args[0]
    return (0.0 <= arg)

def check_pow(config, args):
    num = args[0]
    exp = args[1]
    if exp < 1.0 and exp != 0.0 and num < 0:
        return False
    return True

def setup_config(config):
    config.add_constant('math.e', math.e)
    config.add_constant('math.pi', math.pi)

    # FIXME: register all (more) math functions
    config.add_func('math.pow', Function(math.pow, 2, FLOAT_TYPES, FLOAT_TYPES, check_args=check_pow))
    config.add_func('math.sqrt', Function(math.sqrt, 1, FLOAT_TYPES, check_args=check_sqrt))
    config.add_func('math.exp', Function(math.exp, 1, FLOAT_TYPES))
    config.add_func('math.log', Function(math.log, 1, FLOAT_TYPES))
    config.add_func('math.ceil', Function(math.ceil, 1, FLOAT_TYPES))
    config.add_func('math.floor', Function(math.floor, 1, FLOAT_TYPES))
    if sys.version_info >= (2, 6):
        config.add_func('math.trunc', Function(math.trunc, 1, FLOAT_TYPES))

