"""
Enable optimizations specific to the Python version, command line
and environment variables.

Only enable these optimizations if you don't control the exact Python version,
command line arguments and environment variables. Don't copy the resulting .pyc
files to another host because the environment may be different. For example,
-Qnew command line option of Python 2.7 changes the division operator.
"""

from astoptimizer.config import Function
from astoptimizer.compatibility import PYTHON3
import platform
import sys

def setup_config(config):
    # On Python 2, the optimizer enables optimization on a/b operator
    # when this feature is used, because the behaviour depends on the
    # -Q command line option

    # When pythonenv feature is enabled, non-BMP strings (ex: "\U0010ffff") are
    # also optimized: chr(), ord(), str.encode(), etc.

    # depend on the Python command line option "-O"
    config.add_constant('__debug__', __debug__)

    # dependg on the Python version
    config.add_constant('sys.hexversion', sys.hexversion)
    config.add_constant('sys.version', sys.version)
    config.add_constant('sys.maxunicode', sys.maxunicode)

    if sys.platform == 'win32':
        config.add_constant('sys.winver', sys.winver)
    if sys.version_info >= (3, 2):
        config.add_constant('sys.abiflags', sys.abiflags)
    if sys.version_info >= (2, 6):
        config.add_constant('sys.dont_write_bytecode', sys.dont_write_bytecode)

    config.add_func('platform.python_version',
                    Function(platform.python_version, 0))
    if sys.version_info >= (2, 6):
        # FIXME: on Python 2.5, it is a list
        config.add_func('platform.python_version_tuple',
                        Function(platform.python_version_tuple, 0))

    # Python < 2.6 doesn't have sys.maxsize
    if hasattr(sys, 'maxsize'):
        config.max_size = sys.maxsize

