#!/usr/bin/env python

# Todo list to prepare a release:
#  - run: ./run_tests.py with Python 2.5, 2.6, 2.7, 3.1, 3.2 and 3.3
#  - edit astoptimizer/version.py: check/set version
#  - edit README: set release date
#  - hg ci
#  - hg tag astoptimizer-x.y
#  - hg push
#  - ./setup.py sdist register upload
#  - upload the tarball to Python Package Index
#  - update the website home page (url, md5 and news)
#
# After the release:
#  - edit astoptimizer/version.py: set version to n+1
#  - edit README: add a new empty section for version n+1
#  - hg ci
#  - hg push

from imp import load_source
from os import path

CLASSIFIERS = [
    'Intended Audience :: Developers',
    'Development Status :: 3 - Alpha',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Natural Language :: English',
    'Programming Language :: Python',
    'Programming Language :: Python :: 3',
    'Topic :: Software Development :: Assemblers',
    'Topic :: Software Development :: Build Tools',
    'Topic :: Software Development :: Code Generators',
    'Topic :: Software Development :: Compilers',
    'Topic :: Software Development :: Libraries :: Python Modules',
    'Topic :: Software Development :: Pre-processors',
]

def main():
    from distutils.core import setup

    metadata = load_source("version", path.join("astoptimizer", "version.py"))

    with open('README') as fp:
        long_description = fp.read()

    install_options = {
        "name": metadata.PACKAGE,
        "version": metadata.VERSION,
        "url": metadata.WEBSITE,
        "download_url": metadata.WEBSITE,
        "author": "Victor Stinner",
        "description": "Experimental AST optimizer for Python",
        "long_description": long_description,
        "classifiers": CLASSIFIERS,
        "license": metadata.LICENSE,
        "packages": ["astoptimizer"],
    }

    setup(**install_options)

if __name__ == "__main__":
    main()


